@@ -1,7 +1,7 @@
 C Output from Public domain Ratfor, version 1.03
-      subroutine bfun(fy,xispd,tpm,epsilon,n,nstate,wrk,beta)
+      subroutine bfun(fy,tpm,epsilon,n,nstate,wrk,beta)
       implicit double precision(a-h,o-z)
-      dimension wrk(nstate), xispd(nstate)
+      dimension wrk(nstate)
       dimension fy(nstate,n), tpm(nstate,nstate), beta(nstate,n)
       one = 1.d0
       zero = 0.d0
